@@ -1,28 +1,7 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
- * Copyright (c) 2017, Intel Corporation
+ * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 #include <glib.h>
 #include <inttypes.h>
@@ -31,14 +10,15 @@
 #include <setjmp.h>
 #include <cmocka.h>
 
+#include "util.h"
 #include "access-broker.h"
 #include "command-attrs.h"
-#include "tcti-echo.h"
+#include "tcti.h"
+#include "tcti-mock.h"
 
 typedef struct test_data {
     AccessBroker *access_broker;
     CommandAttrs *command_attrs;
-    Tcti         *tcti;
 } test_data_t;
 
 /* Setup function to allocate our Random gobject. */
@@ -46,15 +26,19 @@ static int
 command_attrs_setup (void **state)
 {
     test_data_t *data;
-    TSS2_RC rc;
+    TSS2_TCTI_CONTEXT *context;
+    Tcti *tcti = NULL;
 
+    context = tcti_mock_init_full ();
+    if (context == NULL) {
+        g_critical ("tcti_mock_init_full failed");
+        return 1;
+    }
     data = calloc (1, sizeof (test_data_t));
-    data->tcti = TCTI (tcti_echo_new (1024));
-    rc = tcti_echo_initialize (TCTI_ECHO (data->tcti));
-    if (rc != TSS2_RC_SUCCESS)
-        g_error ("failed to initialize the echo TCTI");
-    data->access_broker = access_broker_new (data->tcti);
+    tcti = tcti_new (context, NULL);
+    data->access_broker = access_broker_new (tcti);
     data->command_attrs = command_attrs_new ();
+    g_clear_object (&tcti);
 
     *state = data;
     return 0;
@@ -65,16 +49,9 @@ command_attrs_init_tpm_setup (void **state)
 {
     test_data_t *data;
     gint         ret;
-    TPMA_CC      hierarchy_attrs  = { .val = TPM_CC_HierarchyControl + 0xff0000 };
-    TPMA_CC      change_pps_attrs = { .val = TPM_CC_ChangePPS + 0xff0000 };
-    TPMA_CC      command_attributes [2] = {
-        {
-            .val = hierarchy_attrs.val,
-        },
-        {
-            .val = change_pps_attrs.val,
-        },
-    };
+    TPMA_CC      hierarchy_attrs  = TPM2_CC_HierarchyControl + 0xff0000;
+    TPMA_CC      change_pps_attrs = TPM2_CC_ChangePPS + 0xff0000;
+    TPMA_CC      command_attributes [2] = { hierarchy_attrs, change_pps_attrs };
 
     command_attrs_setup (state);
     data = *state;
@@ -111,6 +88,7 @@ command_attrs_type_test (void **state)
 TSS2_SYS_CONTEXT*
 __wrap_access_broker_lock_sapi (AccessBroker *access_broker)
 {
+    UNUSED_PARAM(access_broker);
     return mock_ptr_type (TSS2_SYS_CONTEXT*);
 }
 /* */
@@ -119,6 +97,7 @@ __wrap_access_broker_get_max_command (AccessBroker *access_broker,
                                       guint        *value)
 {
     TSS2_RC rc;
+    UNUSED_PARAM(access_broker);
 
     *value = mock_type (guint);
     g_debug ("value: 0x%" PRIx32, *value);
@@ -130,16 +109,22 @@ __wrap_access_broker_get_max_command (AccessBroker *access_broker,
 /* */
 TSS2_RC
 __wrap_Tss2_Sys_GetCapability (TSS2_SYS_CONTEXT         *sysContext,
-                               TSS2_SYS_CMD_AUTHS const *cmdAuthsArray,
-                               TPM_CAP                   capability,
+                               TSS2L_SYS_AUTH_COMMAND const *cmdAuthsArray,
+                               TPM2_CAP                   capability,
                                UINT32                    property,
                                UINT32                    propertyCount,
                                TPMI_YES_NO              *moreData,
                                TPMS_CAPABILITY_DATA     *capabilityData,
-                               TSS2_SYS_RSP_AUTHS       *rspAuthsArray)
+                               TSS2L_SYS_AUTH_RESPONSE  *rspAuthsArray)
 {
     TPMA_CC *command_attrs;
-    gint i;
+    unsigned int i;
+    UNUSED_PARAM(sysContext);
+    UNUSED_PARAM(cmdAuthsArray);
+    UNUSED_PARAM(capability);
+    UNUSED_PARAM(property);
+    UNUSED_PARAM(moreData);
+    UNUSED_PARAM(rspAuthsArray);
 
     capabilityData->data.command.count = propertyCount;
     command_attrs = mock_ptr_type (TPMA_CC*);
@@ -157,14 +142,7 @@ command_attrs_init_tpm_success_test (void **state)
 {
     test_data_t *data = *state;
     gint         ret = -1;
-    TPMA_CC      command_attributes [2] = {
-        {
-            .val = 0xdeadbeef,
-        },
-        {
-            .val = 0xfeebdaed,
-        },
-    };
+    TPMA_CC      command_attributes [2] = { 0xdeadbeef, 0xfeebdaed };
 
     will_return (__wrap_access_broker_lock_sapi, 1);
     will_return (__wrap_access_broker_get_max_command, 2);
@@ -237,14 +215,7 @@ command_attrs_init_tpm_fail_get_capability_test (void **state)
 {
     test_data_t *data = *state;
     gint         ret = -1;
-    TPMA_CC      command_attributes [2] = {
-        {
-            .val = 0xdeadbeef,
-        },
-        {
-            .val = 0xfeebdaed,
-        },
-    };
+    TPMA_CC      command_attributes [2] = { 0xdeadbeef, 0xfeebdaed };
 
     will_return (__wrap_access_broker_lock_sapi, 1);
     will_return (__wrap_access_broker_get_max_command, 2);
@@ -267,18 +238,18 @@ command_attrs_from_cc_success_test (void **state)
     TPMA_CC      ret_attrs;
 
     /*
-     * TPM_CC_HierarchyControl *is* one of the TPM_CCs populated in the
+     * TPM2_CC_HierarchyControl *is* one of the TPM2_CCs populated in the
      * init_setup function.
      */
     ret_attrs = command_attrs_from_cc (data->command_attrs,
-                                       TPM_CC_HierarchyControl);
-    assert_int_equal (ret_attrs.val & 0x7fff, TPM_CC_HierarchyControl);
+                                       TPM2_CC_HierarchyControl);
+    assert_int_equal (ret_attrs & 0x7fff, TPM2_CC_HierarchyControl);
 }
 /*
  * Test a failed call to the command_attrs_from_cc function. This relies
  * on command_attrs_init_tpm_setup to call the _init function successfully which
  * populates the CommandAttrs object with TPMA_CCs. This time we supply a
- * TPM_CC that isn't populated in the _init function so the call fails.
+ * TPM2_CC that isn't populated in the _init function so the call fails.
  */
 static void
 command_attrs_from_cc_fail_test (void **state)
@@ -287,17 +258,17 @@ command_attrs_from_cc_fail_test (void **state)
     TPMA_CC      ret_attrs;
 
     /*
-     * TPM_CC_EvictControl is *not* one of the TPM_CCs populated in the
+     * TPM2_CC_EvictControl is *not* one of the TPM2_CCs populated in the
      * init_setup function
      */
     ret_attrs = command_attrs_from_cc (data->command_attrs,
-                                       TPM_CC_EvictControl);
-    assert_int_equal (ret_attrs.val, 0);
+                                       TPM2_CC_EvictControl);
+    assert_int_equal (ret_attrs, 0);
 }
 gint
-main (gint    argc,
-      gchar  *argv[])
+main (void)
 {
+    util_init ();
     const struct CMUnitTest tests[] = {
         cmocka_unit_test_setup_teardown (command_attrs_type_test,
                                          command_attrs_setup,
@@ -323,7 +294,6 @@ main (gint    argc,
         cmocka_unit_test_setup_teardown (command_attrs_from_cc_fail_test,
                                          command_attrs_init_tpm_setup,
                                          command_attrs_teardown),
-        NULL,
     };
     return cmocka_run_group_tests (tests, NULL, NULL);
 }
