@@ -1,152 +1,106 @@
+/* SPDX-License-Identifier: BSD-2 */
 /*
- * Copyright (c) 2017, Intel Corporation
+ * Copyright (c) 2017 - 2018, Intel Corporation
  * All rights reserved.
- *
- * Redistribution and use in source and binary forms, with or without
- * modification, are permitted provided that the following conditions are met:
- *
- * 1. Redistributions of source code must retain the above copyright notice,
- * this list of conditions and the following disclaimer.
- *
- * 2. Redistributions in binary form must reproduce the above copyright notice,
- * this list of conditions and the following disclaimer in the documentation
- * and/or other materials provided with the distribution.
- *
- * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
- * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
- * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
- * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE
- * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
- * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
- * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
- * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
- * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
- * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
- * THE POSSIBILITY OF SUCH DAMAGE.
  */
 /*
  * These are common functions used by the integration tests.
  */
 #include <glib.h>
+#include <stdlib.h>
 
 #include "common.h"
-#include "tcti-tabrmd.h"
+#include "tss2-tcti-tabrmd.h"
 #include "tpm2-struct-init.h"
 
-/*
- * Instantiate a TCTI context for communication with the tabrmd.
- */
 TSS2_RC
-tcti_context_init (TSS2_TCTI_CONTEXT **tcti_context)
+get_context_gap_max (TSS2_SYS_CONTEXT *sys_context,
+                     UINT32 *value)
 {
-    TSS2_TCTI_CONTEXT *tmp_tcti_context;
+    TPMI_YES_NO more_data = TPM2_NO;
+    TPMS_CAPABILITY_DATA capability_data;
     TSS2_RC rc;
-    size_t context_size;
 
-    if (tcti_context == NULL)
-        g_error ("tcti_context_init passed NULL reference");
-    rc = tss2_tcti_tabrmd_init (NULL, &context_size);
-    if (rc != TSS2_RC_SUCCESS)
-        g_error ("failed to get size of tcti context");
-    g_debug ("tcti size is: %zd", context_size);
-    tmp_tcti_context = calloc (1, context_size);
-    if (tmp_tcti_context == NULL)
-        g_error ("failed to allocate memory for tcti context");
-    g_debug ("context structure allocated successfully");
-    rc = tss2_tcti_tabrmd_init (tmp_tcti_context, NULL);
-    if (rc != TSS2_RC_SUCCESS)
-        g_error ("failed to initialize tcti context. TSS2_RC: 0x%" PRIx32, rc);
-
-    *tcti_context = tmp_tcti_context;
-    return rc;
-}
-/*
- * Initialize a SAPI context using the TCTI context provided by the caller.
- * This function allocates memory for the SAPI context and returns it to the
- * caller. This memory must be freed by the caller.
- */
-TSS2_RC
-sapi_context_init (TSS2_SYS_CONTEXT  **sapi_context,
-                   TSS2_TCTI_CONTEXT  *tcti_context)
-{
-    TSS2_SYS_CONTEXT *tmp_sapi_context;
-    TSS2_RC rc;
-    size_t size;
-    TSS2_ABI_VERSION abi_version = {
-        .tssCreator = TSSWG_INTEROP,
-        .tssFamily  = TSS_SAPI_FIRST_FAMILY,
-        .tssLevel   = TSS_SAPI_FIRST_LEVEL,
-        .tssVersion = TSS_SAPI_FIRST_VERSION,
-    };
-
-    if (sapi_context == NULL || tcti_context == NULL)
-        g_error ("sapi_context_init passed NULL reference");
-    size = Tss2_Sys_GetContextSize (0);
-    tmp_sapi_context = (TSS2_SYS_CONTEXT*)calloc (1, size);
-    if (tmp_sapi_context == NULL) {
-        g_error ("Failed to allocate %zd bytes for the SAPI context", size);
-    }
-    rc = Tss2_Sys_Initialize (tmp_sapi_context, size, tcti_context, &abi_version);
+    g_debug ("%s: GetCapability", __func__);
+    rc = Tss2_Sys_GetCapability (sys_context,
+                                 NULL,
+                                 TPM2_CAP_TPM_PROPERTIES,
+                                 TPM2_PT_CONTEXT_GAP_MAX,
+                                 1,
+                                 &more_data,
+                                 &capability_data,
+                                 NULL);
     if (rc != TSS2_RC_SUCCESS) {
-        g_warning ("Failed to initialize SAPI context: 0x%" PRIx32, rc);
-        free (tmp_sapi_context);
-        return rc;
+        g_error ("%s: GetCapability failed with RC: 0x%" PRIx32, __func__, rc);
     }
-
-    *sapi_context = tmp_sapi_context;
+    if (capability_data.capability != TPM2_CAP_TPM_PROPERTIES) {
+        g_error ("%s: capability returned is unexpected value: 0x%" PRIx32,
+                 __func__, capability_data.capability);
+    }
+    if (capability_data.data.tpmProperties.count != 1) {
+        g_error ("%s: capability returned is unexpected count: 0x%" PRIx32,
+                 __func__, capability_data.data.tpmProperties.count);
+    }
+    if (capability_data.data.tpmProperties.tpmProperty[0].property != TPM2_PT_CONTEXT_GAP_MAX) {
+        g_error ("%s: capability returned wrong property: 0x%" PRIx32,
+                 __func__, capability_data.data.tpmProperties.tpmProperty[0].property);
+    }
+    g_debug ("%s: TPM2_PT_CONTEXT_GAP_MAX value: 0x%" PRIx32, __func__,
+             capability_data.data.tpmProperties.tpmProperty[0].value);
+    *value = capability_data.data.tpmProperties.tpmProperty[0].value;
     return rc;
 }
 /*
  */
 TSS2_RC
 create_primary (TSS2_SYS_CONTEXT *sapi_context,
-                TPM_HANDLE       *handle)
+                TPM2_HANDLE       *handle)
 {
     TSS2_RC rc;
-    TPM2B_SENSITIVE_CREATE in_sensitive    = { 0 };
-    TPM2B_PUBLIC           in_public       = { 0 };
-    TPM2B_DATA             outside_info    = { 0 };
-    TPML_PCR_SELECTION     creation_pcr    = { 0 };
-    TPM2B_PUBLIC           out_public      = { 0 };
-    TPM2B_CREATION_DATA    creation_data   = { 0 };
+    TPM2B_SENSITIVE_CREATE in_sensitive    = TPM2B_SENSITIVE_CREATE_ZERO_INIT;
+    TPM2B_PUBLIC           in_public       = TPM2B_PUBLIC_ZERO_INIT;
+    TPM2B_DATA             outside_info    = TPM2B_DATA_ZERO_INIT;
+    TPML_PCR_SELECTION     creation_pcr    = TPML_PCR_SELECTION_ZERO_INIT;
+    TPM2B_PUBLIC           out_public      = TPM2B_PUBLIC_ZERO_INIT;
+    TPM2B_CREATION_DATA    creation_data   = TPM2B_CREATION_DATA_ZERO_INIT;
     TPM2B_DIGEST           creation_digest = TPM2B_DIGEST_STATIC_INIT;
-    TPMT_TK_CREATION       creation_ticket = { 0 };
+    TPMT_TK_CREATION       creation_ticket = TPMT_TK_CREATION_ZERO_INIT;
     TPM2B_NAME             name            = TPM2B_NAME_STATIC_INIT;
     /* command auth stuff */
-    TPMS_AUTH_COMMAND auth_command = { .sessionHandle = TPM_RS_PW, };
-    TPMS_AUTH_COMMAND *auth_command_array[1] = { &auth_command, };
-    TSS2_SYS_CMD_AUTHS cmd_auths = {
-        .cmdAuthsCount = 1,
-        .cmdAuths      = auth_command_array,
+    TSS2L_SYS_AUTH_COMMAND cmd_auths = {
+        .count = 1,
+        .auths = {{
+            .sessionHandle = TPM2_RS_PW,
+        }}
     };
 
     /* prepare in_sensitive */
-    in_sensitive.t.size = in_sensitive.t.sensitive.userAuth.t.size + 2;
+    in_sensitive.size = in_sensitive.sensitive.userAuth.size + 2;
     /* prepare in_public TPMT_PUBLIC */
     /* TPMI_ALG_PUBLIC / publicArea */
-    in_public.t.publicArea.type    = TPM_ALG_RSA;
+    in_public.publicArea.type    = TPM2_ALG_RSA;
     /* TPMI_ALG_HASH / nameAlg */
-    in_public.t.publicArea.nameAlg = TPM_ALG_SHA256;
+    in_public.publicArea.nameAlg = TPM2_ALG_SHA256;
     /* TPMA_OBJECT / objectAttributes */
-    in_public.t.publicArea.objectAttributes.val = \
+    in_public.publicArea.objectAttributes = \
         TPMA_OBJECT_FIXEDTPM            | TPMA_OBJECT_FIXEDPARENT  | \
         TPMA_OBJECT_SENSITIVEDATAORIGIN | TPMA_OBJECT_USERWITHAUTH | \
         TPMA_OBJECT_RESTRICTED          | TPMA_OBJECT_DECRYPT;
     /* TPM2B_DIGEST / authPolicy */
-    in_public.t.publicArea.authPolicy.t.size = 0;
-    /* TPMU_PUBLIC_PARAMS / parameters: key type is TPM_ALG_RSA, set parameters accordingly */
-    in_public.t.publicArea.parameters.rsaDetail.symmetric.algorithm = TPM_ALG_AES;
-    in_public.t.publicArea.parameters.rsaDetail.symmetric.keyBits.aes = 128;
-    in_public.t.publicArea.parameters.rsaDetail.symmetric.mode.aes = TPM_ALG_CFB;
-    in_public.t.publicArea.parameters.rsaDetail.scheme.scheme = TPM_ALG_NULL;
-    in_public.t.publicArea.parameters.rsaDetail.keyBits = 2048;
-    in_public.t.publicArea.parameters.rsaDetail.exponent = 0;
+    in_public.publicArea.authPolicy.size = 0;
+    /* TPMU_PUBLIC_PARAMS / parameters: key type is TPM2_ALG_RSA, set parameters accordingly */
+    in_public.publicArea.parameters.rsaDetail.symmetric.algorithm = TPM2_ALG_AES;
+    in_public.publicArea.parameters.rsaDetail.symmetric.keyBits.aes = 128;
+    in_public.publicArea.parameters.rsaDetail.symmetric.mode.aes = TPM2_ALG_CFB;
+    in_public.publicArea.parameters.rsaDetail.scheme.scheme = TPM2_ALG_NULL;
+    in_public.publicArea.parameters.rsaDetail.keyBits = 2048;
+    in_public.publicArea.parameters.rsaDetail.exponent = 0;
     /* TPMU_PUBLIC_ID / unique */
-    in_public.t.publicArea.unique.rsa.t.size = 0;
+    in_public.publicArea.unique.rsa.size = 0;
 
     rc = TSS2_RETRY_EXP (Tss2_Sys_CreatePrimary (
         sapi_context,
-        TPM_RH_NULL,      /* in: hierarchy */
+        TPM2_RH_NULL,      /* in: hierarchy */
         &cmd_auths,       /* in: in sessions / auths */
         &in_sensitive,    /* in: sensitive data? */
         &in_public,       /* in: key template */
@@ -172,43 +126,43 @@ create_primary (TSS2_SYS_CONTEXT *sapi_context,
  */
 TSS2_RC
 create_key (TSS2_SYS_CONTEXT *sapi_context,
-            TPM_HANDLE        parent_handle,
+            TPM2_HANDLE        parent_handle,
             TPM2B_PRIVATE    *out_private,
             TPM2B_PUBLIC     *out_public)
 {
-    TPM_RC rc;
+    TSS2_RC rc;
 
-    TPM2B_SENSITIVE_CREATE  in_sensitive     = { 0 };
-    TPM2B_PUBLIC	    in_public        = { 0 };
-    TPM2B_DATA	            outside_info     = { 0 };
-    TPML_PCR_SELECTION	    creation_pcr     = { 0 };
-    TPM2B_CREATION_DATA	    creation_data    = { 0 };
-    TPM2B_DIGEST	    creation_hash    = TPM2B_DIGEST_STATIC_INIT;
-    TPMT_TK_CREATION	    creation_ticket  = { 0 };
-    TPMS_AUTH_COMMAND auth_command           = { .sessionHandle = TPM_RS_PW, };
-    TPMS_AUTH_COMMAND *auth_command_array[1] = { &auth_command, };
-    TSS2_SYS_CMD_AUTHS cmd_auths = {
-        .cmdAuthsCount = 1,
-        .cmdAuths      = auth_command_array,
+    TPM2B_SENSITIVE_CREATE in_sensitive    = TPM2B_SENSITIVE_CREATE_ZERO_INIT;
+    TPM2B_PUBLIC           in_public       = TPM2B_PUBLIC_ZERO_INIT;
+    TPM2B_DATA             outside_info    = TPM2B_DATA_ZERO_INIT;
+    TPML_PCR_SELECTION     creation_pcr    = TPML_PCR_SELECTION_ZERO_INIT;
+    TPM2B_CREATION_DATA    creation_data   = TPM2B_CREATION_DATA_ZERO_INIT;
+    TPM2B_DIGEST           creation_hash   = TPM2B_DIGEST_STATIC_INIT;
+    TPMT_TK_CREATION       creation_ticket = TPMT_TK_CREATION_ZERO_INIT;
+    TSS2L_SYS_AUTH_COMMAND cmd_auths = {
+        .count = 1,
+        .auths = {{
+            .sessionHandle = TPM2_RS_PW,
+        }}
     };
 
     g_debug ("create_key with parent_handle: 0x%" PRIx32, parent_handle);
-    in_sensitive.t.size = in_sensitive.t.sensitive.userAuth.t.size + 2;
-    in_public.t.publicArea.type = TPM_ALG_RSA;
-    in_public.t.publicArea.nameAlg = TPM_ALG_SHA256;
-    in_public.t.publicArea.objectAttributes.val = \
+    in_sensitive.size = in_sensitive.sensitive.userAuth.size + 2;
+    in_public.publicArea.type = TPM2_ALG_RSA;
+    in_public.publicArea.nameAlg = TPM2_ALG_SHA256;
+    in_public.publicArea.objectAttributes = \
         TPMA_OBJECT_FIXEDTPM            | TPMA_OBJECT_FIXEDPARENT  | \
         TPMA_OBJECT_SENSITIVEDATAORIGIN | TPMA_OBJECT_USERWITHAUTH | \
-        TPMA_OBJECT_DECRYPT             | TPMA_OBJECT_SIGN;
+        TPMA_OBJECT_DECRYPT             | TPMA_OBJECT_SIGN_ENCRYPT;
     /* TPM2B_DIGEST / authPolicy */
-    in_public.t.publicArea.authPolicy.t.size = 0;
-    /* TPMU_PUBLIC_PARAMS / parameters: key type is TPM_ALG_RSA, set parameters accordingly */
-    in_public.t.publicArea.parameters.rsaDetail.symmetric.algorithm = TPM_ALG_NULL;
-    in_public.t.publicArea.parameters.rsaDetail.scheme.scheme = TPM_ALG_NULL;
-    in_public.t.publicArea.parameters.rsaDetail.keyBits = 2048;
-    in_public.t.publicArea.parameters.rsaDetail.exponent = 0;
+    in_public.publicArea.authPolicy.size = 0;
+    /* TPMU_PUBLIC_PARAMS / parameters: key type is TPM2_ALG_RSA, set parameters accordingly */
+    in_public.publicArea.parameters.rsaDetail.symmetric.algorithm = TPM2_ALG_NULL;
+    in_public.publicArea.parameters.rsaDetail.scheme.scheme = TPM2_ALG_NULL;
+    in_public.publicArea.parameters.rsaDetail.keyBits = 2048;
+    in_public.publicArea.parameters.rsaDetail.exponent = 0;
     /* TPMU_PUBLIC_ID / unique */
-    in_public.t.publicArea.unique.rsa.t.size = 0;
+    in_public.publicArea.unique.rsa.size = 0;
 
     g_print ("Tss2_Sys_Create with parent handle: 0x%" PRIx32 "\n",
              parent_handle);
@@ -242,18 +196,18 @@ create_key (TSS2_SYS_CONTEXT *sapi_context,
  */
 TSS2_RC
 load_key (TSS2_SYS_CONTEXT *sapi_context,
-          TPM_HANDLE        parent_handle,
-          TPM_HANDLE       *out_handle,
+          TPM2_HANDLE        parent_handle,
+          TPM2_HANDLE       *out_handle,
           TPM2B_PRIVATE    *in_private,
           TPM2B_PUBLIC     *in_public)
 {
     TSS2_RC            rc;
     TPM2B_NAME         name                  = TPM2B_NAME_STATIC_INIT;
-    TPMS_AUTH_COMMAND  auth_command          = { .sessionHandle = TPM_RS_PW, };
-    TPMS_AUTH_COMMAND *auth_command_array[1] = { &auth_command, };
-    TSS2_SYS_CMD_AUTHS cmd_auths             = {
-        .cmdAuthsCount = 1,
-        .cmdAuths      = auth_command_array,
+    TSS2L_SYS_AUTH_COMMAND cmd_auths = {
+        .count = 1,
+        .auths = {{
+            .sessionHandle = TPM2_RS_PW,
+        }}
     };
 
     g_print ("Tss2_Sys_Load with parent handle: 0x%" PRIx32 "\n  in_private: "
@@ -280,14 +234,14 @@ load_key (TSS2_SYS_CONTEXT *sapi_context,
 }
 TSS2_RC
 undefine_nv_index (TSS2_SYS_CONTEXT *sapi_context,
-                   TPM_HANDLE        index)
+                   TPM2_HANDLE        index)
 {
     TSS2_RC rc;
-    TPMS_AUTH_COMMAND  auth_command          = { .sessionHandle = TPM_RS_PW, };
-    TPMS_AUTH_COMMAND *auth_command_array[1] = { &auth_command, };
-    TSS2_SYS_CMD_AUTHS cmd_auths             = {
-        .cmdAuthsCount = 1,
-        .cmdAuths      = auth_command_array,
+    TSS2L_SYS_AUTH_COMMAND cmd_auths = {
+        .count = 1,
+        .auths = {{
+            .sessionHandle = TPM2_RS_PW,
+        }}
     };
 
     g_debug ("undefine_nv_index: sapi_context: 0x%" PRIxPTR " index: 0x%"
@@ -297,7 +251,7 @@ undefine_nv_index (TSS2_SYS_CONTEXT *sapi_context,
     }
 
     rc = Tss2_Sys_NV_UndefineSpace (sapi_context,
-                                    TPM_RH_OWNER,
+                                    TPM2_RH_OWNER,
                                     index,
                                     &cmd_auths,
                                     0);
@@ -310,7 +264,7 @@ undefine_nv_index (TSS2_SYS_CONTEXT *sapi_context,
 }
 TSS2_RC
 save_context (TSS2_SYS_CONTEXT *sapi_context,
-              TPM_HANDLE        handle,
+              TPM2_HANDLE        handle,
               TPMS_CONTEXT     *context)
 {
     TSS2_RC rc;
@@ -332,7 +286,7 @@ save_context (TSS2_SYS_CONTEXT *sapi_context,
 }
 TSS2_RC
 flush_context (TSS2_SYS_CONTEXT *sapi_context,
-               TPM_HANDLE        handle)
+               TPM2_HANDLE        handle)
 {
     TSS2_RC rc;
 
@@ -352,14 +306,14 @@ flush_context (TSS2_SYS_CONTEXT *sapi_context,
 }
 TSS2_RC
 evict_persistent_objs (TSS2_SYS_CONTEXT *sapi_context,
-                       TPM_HANDLE        handle)
+                       TPM2_HANDLE        handle)
 {
     TSS2_RC rc;
-    TPMS_AUTH_COMMAND  auth_command          = { .sessionHandle = TPM_RS_PW, };
-    TPMS_AUTH_COMMAND *auth_command_array[1] = { &auth_command, };
-    TSS2_SYS_CMD_AUTHS cmd_auths             = {
-        .cmdAuthsCount = 1,
-        .cmdAuths      = auth_command_array,
+    TSS2L_SYS_AUTH_COMMAND cmd_auths = {
+        .count = 1,
+        .auths = {{
+            .sessionHandle = TPM2_RS_PW,
+        }}
     };
 
     g_debug ("evict_persistent_objs: sapi_context: 0x%" PRIxPTR
@@ -368,10 +322,10 @@ evict_persistent_objs (TSS2_SYS_CONTEXT *sapi_context,
         g_error ("evict_persistent_objs passed NULL reference");
     }
 
-    rc = Tss2_Sys_EvictControl (sapi_context, TPM_RH_OWNER,
+    rc = Tss2_Sys_EvictControl (sapi_context, TPM2_RH_OWNER,
                                 handle, &cmd_auths,
                                 handle, NULL);
-    if (rc != TPM_RC_SUCCESS) {
+    if (rc != TPM2_RC_SUCCESS) {
         g_warning ("Tss2_Sys_EvictControl: failed to evict control for "
                    "handle: 0x%" PRIx32 " TSS2_RC: 0x%" PRIx32, handle, rc);
     }
@@ -382,7 +336,7 @@ void
 clean_up_all (TSS2_SYS_CONTEXT *sapi_context)
 {
     TSS2_RC rc;
-    int i, j;
+    unsigned int i, j;
     TPMI_YES_NO more_data;
     TPMS_CAPABILITY_DATA capability_data;
     TPML_HANDLE *handles = &capability_data.data.handles;
@@ -391,27 +345,31 @@ clean_up_all (TSS2_SYS_CONTEXT *sapi_context)
         UINT32 count;
     } properties[] = {
         {
-            .property = PERSISTENT_FIRST,
-            .count = MAX_CAP_HANDLES,
+            .property = TPM2_PERSISTENT_FIRST,
+            .count = TPM2_MAX_CAP_HANDLES,
         },
         {
-            .property = TRANSIENT_FIRST,
-            .count = MAX_CAP_HANDLES,
+            .property = TPM2_TRANSIENT_FIRST,
+            .count = TPM2_MAX_CAP_HANDLES,
         },
         {
-            .property = NV_INDEX_FIRST,
-            .count = MAX_CAP_HANDLES,
+            .property = TPM2_NV_INDEX_FIRST,
+            .count = TPM2_MAX_CAP_HANDLES,
         },
         {
-            .property = POLICY_SESSION_FIRST,
-            .count = MAX_CAP_HANDLES,
+            .property = TPM2_LOADED_SESSION_FIRST,
+            .count = TPM2_MAX_CAP_HANDLES,
         },
+        {
+            .property = TPM2_ACTIVE_SESSION_FIRST,
+            .count = TPM2_MAX_CAP_HANDLES,
+        }
     };
 
     for (i = 0; i < sizeof(properties) / sizeof(struct property_info); ++i) {
         rc = Tss2_Sys_GetCapability (sapi_context,
                                      NULL,
-                                     TPM_CAP_HANDLES,
+                                     TPM2_CAP_HANDLES,
                                      properties[i].property,
                                      properties[i].count,
                                      &more_data,
@@ -419,14 +377,14 @@ clean_up_all (TSS2_SYS_CONTEXT *sapi_context)
                                      NULL);
         if (rc != TSS2_RC_SUCCESS) {
              g_warning ("Tss2_Sys_GetCapability: failed to get capability for "
-                        "handles propery: 0x%" PRIx32 " count: 0x%" PRIx32
+                        "handles property: 0x%" PRIx32 " count: 0x%" PRIx32
                         " TSS2_RC: 0x%" PRIx32, properties[i].property,
                         properties[i].count, rc);
              continue;
         }
 
         for (j = 0; j < handles->count; ++j) {
-            if (properties[i].property == NV_INDEX_FIRST) {
+            if (properties[i].property == (UINT32) TPM2_NV_INDEX_FIRST) {
                 undefine_nv_index (sapi_context, handles->handle[j]);
                 continue;
             }
@@ -436,7 +394,7 @@ clean_up_all (TSS2_SYS_CONTEXT *sapi_context)
              * objects from the TPM. So we always handle persistent handles
              * prior to transient handles to allow evicting them on next round.
              */
-            if (properties[i].property == PERSISTENT_FIRST) {
+            if (properties[i].property == (UINT32) TPM2_PERSISTENT_FIRST) {
                 evict_persistent_objs (sapi_context, handles->handle[j]);
                 continue;
             }
@@ -446,7 +404,7 @@ clean_up_all (TSS2_SYS_CONTEXT *sapi_context)
     }
 }
 /*
- * This fucntion is a very simple wrapper around the TPM2_StartAuthSession
+ * This function is a very simple wrapper around the TPM2_StartAuthSession
  * function. It uses the most simple / default values to create an unsalted,
  * unbound session.
  */
@@ -456,35 +414,31 @@ start_auth_session (TSS2_SYS_CONTEXT      *sapi_context,
 {
     TSS2_RC rc;
     TPM2B_NONCE nonce_caller = {
-        .t = {
-            .size   = SHA256_DIGEST_SIZE,
-            .buffer = {
-                0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef,
-                0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef,
-                0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef,
-                0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef
-            }
+        .size   = TPM2_SHA256_DIGEST_SIZE,
+        .buffer = {
+            0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef,
+            0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef,
+            0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef,
+            0xde, 0xad, 0xbe, 0xef, 0xde, 0xad, 0xbe, 0xef
         }
     };
     TPM2B_NONCE nonce_tpm = {
-        .t = {
-            .size   = SHA256_DIGEST_SIZE,
-            .buffer = { 0 }
-        }
+        .size   = TPM2_SHA256_DIGEST_SIZE,
+        .buffer = { 0 }
     };
-    TPM2B_ENCRYPTED_SECRET encrypted_salt = { 0 };
-    TPMT_SYM_DEF           symmetric      = { .algorithm = TPM_ALG_NULL };
+    TPM2B_ENCRYPTED_SECRET encrypted_salt = TPM2B_ENCRYPTED_SECRET_ZERO_INIT;
+    TPMT_SYM_DEF           symmetric      = { .algorithm = TPM2_ALG_NULL };
 
     g_debug ("StartAuthSession for TPM_SE_POLICY (policy session)");
     rc = Tss2_Sys_StartAuthSession (sapi_context,
-                                    TPM_RH_NULL,     /* tpmKey */
-                                    TPM_RH_NULL,     /* bind */
+                                    TPM2_RH_NULL,     /* tpmKey */
+                                    TPM2_RH_NULL,     /* bind */
                                     0,               /* cmdAuthsArray */
                                     &nonce_caller,   /* nonceCaller */
                                     &encrypted_salt, /* encryptedSalt */
-                                    TPM_SE_POLICY,   /* sessionType */
+                                    TPM2_SE_POLICY,   /* sessionType */
                                     &symmetric,      /* symmetric */
-                                    TPM_ALG_SHA256,  /* authHash */
+                                    TPM2_ALG_SHA256,  /* authHash */
                                     session_handle,  /* sessionHandle */
                                     &nonce_tpm,      /* nonceTPM */
                                     0                /* rspAuthsArray */
